@@ -29,7 +29,7 @@ either expressed or implied, of Samsung Electronics Co.,Ltd..
 
 """
 opencl4py - OpenCL cffi bindings and helper classes.
-URL: https://github.com/ajkxyz/opencl4py
+URL: https://github.com/Samsung/opencl4py
 Original author: Alexey Kazantsev <a.kazantsev@samsung.com>
 """
 
@@ -38,7 +38,7 @@ Init module.
 """
 
 # High-level interface.
-from opencl4py._py import Platforms, Context, CLRuntimeError
+from opencl4py._py import Platforms, Context, CLRuntimeError, skip
 
 # Low-level interface.
 from opencl4py._cffi import ffi, lib, initialize
